@@ -8,7 +8,7 @@
 'use strict'
 var express = require('express'),
     router = express.Router(),
-    inspect = require('security-middleware')
+    inspect = require('@stolostron/security-middleware')
 
 //controllers
 var app = require('./app'),
